Garfield: **G**raph-based Contrastive Le**ar**ning enables **F**ast S**i**ngle-C**el**l Embe**d**ding
========================================================================

Garfield is a novel graph representation algorithm with contrastive learning to embed cells into the same latent space. The joint embedding of cells allows Garfield to perform various types of single cell or spatial tasks, including scRNA-seq, scATAC-seq and scProtein clustering, batch correction, multi-omics integration, spatial domain discovery and label transfer of spatial data with scRNA-seq data.

.. image:: _static/img/Garfield_framework.png
   :align: center
   :width: 700
   :alt: Garfield overview


.. toctree::
   :maxdepth: 2
   :caption: Overview
   :hidden:

   About Garfield
   Installation
   API
   Release notes
   Citation


.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   01.panc8_all_batch_correction
   02.panc_mapping
   03.10x_pbmc_paired_scMulti_analysis
   04.Garfield_spatia_molecular_niche_seqFISH_Mouse_Organogenesis
   05.Garfield_spatial_niche_slideseqv2_mouse_hippocampus
   06.Garfield_spMulti_mouse_brain




